==> makumba-0_6-src.zip: makumba/classes/org/makumba/NoSuchFieldException.java <==
///////////////////////////////
//  Makumba, Makumba tag library
//  Copyright (C) 2000-2003  http://www.makumba.org
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
//  -------------
//  $Id: NoSuchFieldException.java,v 2.2 2006/01/20 03:12:11 manuel_gay Exp $
//  $Name: makumba-0_6 $
/////////////////////////////////////

package org.makumba;

/**
 * This exception occurs when a field of a makumba type is mentioned but does not exist. This is a programmer error, it
 * should be fixed, not caught
 */
public class NoSuchFieldException extends RuntimeException {
    /**
     * 
     */
    private static final long serialVersionUID = 1L;

    /** indicate the missing pointer */
    public NoSuchFieldException(DataDefinition dd, String message) {
        super("type " + dd.getName() + " : " + message);
    }

    public NoSuchFieldException(String label) {
        super("label " + label);
    }
}

==> makumba-0_8_0_2-src.zip: makumba/classes/org/makumba/NoSuchFieldException.java <==
///////////////////////////////
//  Makumba, Makumba tag library
//  Copyright (C) 2000-2003  http://www.makumba.org
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
//  -------------
//  $Id: NoSuchFieldException.java 2538 2008-06-11 10:46:01Z rosso_nero $
//  $Name$
/////////////////////////////////////

package org.makumba;

/**
 * This exception occurs when a field of a makumba type is mentioned but does not exist. This is a programmer error, it
 * should be fixed, not caught
 */
public class NoSuchFieldException extends RuntimeException {
    /**
     * 
     */
    private static final long serialVersionUID = 1L;

    /** indicate the missing pointer */
    public NoSuchFieldException(DataDefinition dd, String message) {
        super("type " + dd.getName() + " : " + message);
    }

    public NoSuchFieldException(String message) {
        super(message);
    }
}
